## 0/20 Follow Dart file conventions

### [x] 0/10 points: Provide a valid `pubspec.yaml`

<details>
<summary>
Homepage URL is insecure.
</summary>

Update the `homepage` field and use a secure (`https`) URL.
</details>
<details>
<summary>
Documentation URL is insecure.
</summary>

Update the `documentation` field and use a secure (`https`) URL.
</details>

### [x] 0/5 points: Provide a valid `README.md`

<details>
<summary>
Links in `README.md` should be secure. 9 links are insecure.
</summary>

`README.md:2:4`

```
  ╷
2 │ <p><a href="http://rikulo.org/projects/stream">Stream</a> is a Dart web server supporting request routing, filtering, template engine, WebSocket, MVC design pattern and file-based static resources.</p>
  │    ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  ╵
```

Use `https` URLs instead.
</details>

### [x] 0/5 points: Provide a valid `CHANGELOG.md`

<details>
<summary>
No `CHANGELOG.md` found.
</summary>

Changelog entries help developers follow the progress of your package. See the [example](https://raw.githubusercontent.com/dart-lang/stagehand/master/templates/package-simple/CHANGELOG.md) generated by `stagehand`.
</details>

## 0/10 Provide documentation

### [x] 0/10 points: Package has an example

<details>
<summary>
No example found.
</summary>

See [package layout](https://dart.dev/tools/pub/package-layout#examples) guidelines on how to add an example.
</details>

## 10/20 Support multiple platforms

### [~] 10/20 points: Supports 1 of 2 possible platforms (**native**, js)

Consider supporting multiple platforms:

<details>
<summary>
Package not compatible with runtime js
</summary>

Because:
* `package:stream/stream.dart` that imports:
* `package:stream/plugin.dart` that imports:
* `package:rikulo_commons/io.dart` that imports:
* `dart:io`
</details>

## 0/30 Pass static analysis

### [x] 0/30 points: code has no errors, warnings, lints, or formatting issues

Found 1227 issues. Showing the first 2:

<details>
<summary>
ERROR: '_ReadOnlyHeaders.add' ('void Function(String, Object)') isn't a valid override of 'HttpHeadersWrapper.add' ('void Function(String, Object, {bool preserveHeaderCase})').
</summary>

`lib/src/connect_impl.dart:281:8`

```
    ╷
281 │   void add(String name, Object value) {
    │        ^^^
    ╵
```

To reproduce make sure you are using [pedantic](https://pub.dev/packages/pedantic#using-the-lints) and run `dartanalyzer lib/src/connect_impl.dart`
</details>
<details>
<summary>
ERROR: '_ReadOnlyHeaders.set' ('void Function(String, Object)') isn't a valid override of 'HttpHeadersWrapper.set' ('void Function(String, Object, {bool preserveHeaderCase})').
</summary>

`lib/src/connect_impl.dart:284:8`

```
    ╷
284 │   void set(String name, Object value) {
    │        ^^^
    ╵
```

To reproduce make sure you are using [pedantic](https://pub.dev/packages/pedantic#using-the-lints) and run `dartanalyzer lib/src/connect_impl.dart`
</details>

## 10/20 Support up-to-date dependencies

### [*] 10/10 points: All of the package dependencies are supported in the latest version

|Package|Constraint|Compatible|Latest|
|:-|:-|:-|:-|
|[`args`]|`any`|1.6.0|1.6.0|
|[`charcode`]|`any`|1.1.3|1.1.3|
|[`http`]|`any`|0.12.2|0.12.2|
|[`logging`]|`any`|0.11.4|0.11.4|
|[`path`]|`any`|1.7.0|1.7.0|
|[`rikulo_commons`]|`any`|4.1.3|4.1.3|

<details><summary>Transitive dependencies</summary>

|Package|Constraint|Compatible|Latest|
|:-|:-|:-|:-|
|[`collection`]|-|1.14.13|1.14.13|
|[`http_parser`]|-|3.1.4|3.1.4|
|[`meta`]|-|1.2.2|1.2.2|
|[`mime`]|-|0.9.7|0.9.7|
|[`pedantic`]|-|1.9.2|1.9.2|
|[`source_span`]|-|1.7.0|1.7.0|
|[`string_scanner`]|-|1.0.5|1.0.5|
|[`term_glyph`]|-|1.1.0|1.1.0|
|[`typed_data`]|-|1.2.0|1.2.0|
</details>

To reproduce run `pub outdated --no-dev-dependencies --up-to-date --no-dependency-overrides`.

[`args`]: https://pub.dev/packages/args
[`charcode`]: https://pub.dev/packages/charcode
[`http`]: https://pub.dev/packages/http
[`logging`]: https://pub.dev/packages/logging
[`path`]: https://pub.dev/packages/path
[`rikulo_commons`]: https://pub.dev/packages/rikulo_commons
[`collection`]: https://pub.dev/packages/collection
[`http_parser`]: https://pub.dev/packages/http_parser
[`meta`]: https://pub.dev/packages/meta
[`mime`]: https://pub.dev/packages/mime
[`pedantic`]: https://pub.dev/packages/pedantic
[`source_span`]: https://pub.dev/packages/source_span
[`string_scanner`]: https://pub.dev/packages/string_scanner
[`term_glyph`]: https://pub.dev/packages/term_glyph
[`typed_data`]: https://pub.dev/packages/typed_data


### [x] 0/10 points: Package supports latest stable Dart and Flutter SDKs

* Found no Flutter in your PATH. Could not determine the current Flutter version.